pub struct MultiListIndexingWordlist { /* private fields */ }Expand description
Some wordlists are actually multiple lists, some have two (i.e. an even and an odd list) but this interface abstracts around having multiple wordlists based on the index of the word in the vec being used to index into which worldlist.
Implementations
Sourceimpl MultiListIndexingWordlist
impl MultiListIndexingWordlist
Sourcepub fn new(
name: String,
wordlists: Vec<Box<[&'static str]>>,
) -> MultiListIndexingWordlist
pub fn new( name: String, wordlists: Vec<Box<[&'static str]>>, ) -> MultiListIndexingWordlist
Create a new wordlist out of multiple lists of words.
Sourcepub fn word(&self, index: &usize, count: usize) -> Result<&'static str>
pub fn word(&self, index: &usize, count: usize) -> Result<&'static str>
Given some index into the wordlist, and the current count of indexes we’re at (i.e. the index into the wordlist and the wordlist index), find the word.
For example, if there are 2 wordlists which make up this multi-list wordlist,
and the index of the word is 15 and the count is 10 (the tenth index in the list);
we would do something like: self.wordlists[10 % 2][index]. Namely, check which
wordlist to query, and then index into it.
Sourcepub fn index(&self, word: &str, count: usize) -> Result<usize>
pub fn index(&self, word: &str, count: usize) -> Result<usize>
Given some word and it’s current count we’re at (i.e. the wordlist index), find the index.
For example, if there are 2 wordlists which make up this multi-list wordlist, and the
count is 10 (the tenth word in the WordVec, we would do something like:
self.wordlists[10 % 2].index_of(word). Namely, check which wordlist to query,
and then retrieve the index.